@@ -12,11 +12,11 @@ from fhirkit.elements import (
     HumanName,
     Identifier,
     Reference,
-    ContactDetail,
-    ContactPoint,
     Address,
-    AdministrativeGender
+    AdministrativeGender,
 )
+from fhirkit.metadata_types import ContactDetail, ContactPoint
+
 
 class Patient(DomainResource):
     resourceType: Literal["Patient"] = Field("Patient", const=True)
@@ -44,4 +44,4 @@ class Patient(DomainResource):
 
     @validator("multipleBirth", pre=True, always=True, allow_reuse=True)
     def validate_multipleBirth(cls, v, values, field):
-        return deterimine_choice_type(cls, v, values, field)
\ No newline at end of file
+        return deterimine_choice_type(cls, v, values, field)
